package com.androidhuman.example.AlertDialogExample;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

public class AlertDialogExample extends Activity implements OnClickListener{
    private static final int DIALOG_OK_CANCEL = 0;
    private static final int DIALOG_LIST = 1;
    private static final int DIALOG_PROGRESS = 2;
    private static final int DIALOG_SINGLE_CHOICE = 3;
    private static final int DIALOG_MULTIPLE_CHOICE = 4;
    private static final int DIALOG_CUSTOM_LAYOUT = 5;
    private ProgressDialog progressDialog;
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        Button okCancelButton = (Button)findViewById(R.id.okCancelButton);
        Button listButton = (Button)findViewById(R.id.listButton);
        Button progressButton = (Button)findViewById(R.id.progressButton);
        Button singleChoiceButton = (Button)findViewById(R.id.singleChoiceButton);
        Button multipleChoiceButton = (Button)findViewById(R.id.multiChoiceButton);
        Button customButton = (Button)findViewById(R.id.customLayoutButton);
        
        okCancelButton.setOnClickListener(this);
        listButton.setOnClickListener(this);
        progressButton.setOnClickListener(this);
        singleChoiceButton.setOnClickListener(this);
        multipleChoiceButton.setOnClickListener(this);
        customButton.setOnClickListener(this);
    }
    
    @Override
    protected Dialog onCreateDialog(int id){
    	switch(id){
    	case DIALOG_OK_CANCEL:
    		return new AlertDialog.Builder(this)
    			.setTitle("OK Cancel Dialog")
    			.setMessage("OK/ Cancel ̾αԴϴ.")
    			.setPositiveButton("OK", new DialogInterface.OnClickListener() {
					
					@Override
					public void onClick(DialogInterface dialog, int which) {
						Toast.makeText(AlertDialogExample.this, "OK", 
								Toast.LENGTH_SHORT).show();
					}
				})
				.setNegativeButton("Cancel", new DialogInterface.OnClickListener() {
					
					@Override
					public void onClick(DialogInterface dialog, int which) {
						Toast.makeText(AlertDialogExample.this, "Cancel", 
								Toast.LENGTH_SHORT).show();						
					}
				}).create();
    		
    	case DIALOG_LIST:
    		return new AlertDialog.Builder(this)
    			.setTitle("List Dialog")
    			.setItems(R.array.lists, new DialogInterface.OnClickListener(){

					@Override
					public void onClick(DialogInterface dialog, int which) {
						Toast.makeText(AlertDialogExample.this, 
								(which+1) + " ° ׸ Ͽϴ.", 
								Toast.LENGTH_SHORT).show();
					}
    				
    			}).create();
    		
    	case DIALOG_PROGRESS:
    		progressDialog = new ProgressDialog(this);
    		progressDialog.setTitle("Progress Dialog");
    		progressDialog.setIcon(android.R.drawable.ic_dialog_info);
    		progressDialog.setMessage("ø ٷ ֽʽÿ..");
    		return progressDialog;
    		
    	case DIALOG_SINGLE_CHOICE:
    		return new AlertDialog.Builder(this)
    			.setIcon(android.R.drawable.ic_dialog_info)
    			.setTitle("Single Choice")
    			.setSingleChoiceItems(R.array.lists, 1, new DialogInterface.OnClickListener() {
					
					@Override
					public void onClick(DialogInterface dialog, int which) {
						Toast.makeText(AlertDialogExample.this, 
								(which+1) + " ° ׸ Ͽϴ.", 
								Toast.LENGTH_SHORT).show();
					}
				}).create();
    		
    	case DIALOG_MULTIPLE_CHOICE:
    		return new AlertDialog.Builder(this)
    			.setIcon(android.R.drawable.ic_dialog_info)
    			.setTitle("Multiple Choice")
    			.setMultiChoiceItems(R.array.lists, new boolean[]{false,true,true,false}, new DialogInterface.OnMultiChoiceClickListener(){

					@Override
					public void onClick(DialogInterface dialog, int which,
							boolean isChecked) {
						Toast.makeText(AlertDialogExample.this, 
								(which+1) + " ° ׸ : " + isChecked, 
								Toast.LENGTH_SHORT).show();						
					}
    				
    			}).create();
    		
    	case DIALOG_CUSTOM_LAYOUT:
    		LayoutInflater inflater = getLayoutInflater();
    		final View customView = inflater.inflate(R.layout.custom_layout, null);
    		return new AlertDialog.Builder(this)
    			.setTitle("Custom Layout")
    			.setView(customView)
    			.setPositiveButton("Ȯ", new DialogInterface.OnClickListener(){

					@Override
					public void onClick(DialogInterface dialog, int which) {
						EditText password = (EditText)customView.findViewById(R.id.password);
						Toast.makeText(AlertDialogExample.this, password.getText().toString(), Toast.LENGTH_LONG).show();
					}
    				
    			}).create();
    	}
    	
    	return null;
    }

	@Override
	public void onClick(View v) {
		switch(v.getId()){
		case R.id.okCancelButton:
			showDialog(DIALOG_OK_CANCEL);
			break;
			
		case R.id.listButton:
			showDialog(DIALOG_LIST);
			break;
			
		case R.id.progressButton:
			showDialog(DIALOG_PROGRESS);
			break;
			
		case R.id.singleChoiceButton:
			showDialog(DIALOG_SINGLE_CHOICE);
			break;
			
		case R.id.multiChoiceButton:
			showDialog(DIALOG_MULTIPLE_CHOICE);
			break;
			
		case R.id.customLayoutButton:
			showDialog(DIALOG_CUSTOM_LAYOUT);
			break;
		}
		
	}
}