package com.androidhuman.example.AudioRecorderExample;

import java.io.File;
import java.io.IOException;

import android.app.Activity;
import android.content.ContentValues;
import android.media.MediaRecorder;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore.Audio;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

public class AudioRecorderExample extends Activity {
	private static final int STATE_IDLE = 0;
	private static final int STATE_RECORDING = 1;
	private static int RECORDING_STATE = STATE_IDLE;
	
    private MediaRecorder mRecorder;
    private EditText pathText;
    private Button recordButton;
    
    private String mediaPath = "";
    private File mediaFile = null;
    
    private void procAudio(int state){
    	switch(state){
    	case STATE_IDLE:
    		initRecorder();
    		mRecorder.start();
    		RECORDING_STATE = STATE_RECORDING;
    		Toast.makeText(AudioRecorderExample.this, " մϴ.", Toast.LENGTH_SHORT).show();
    		pathText.setEnabled(false);
    		recordButton.setText("");
    		break;
    		
    	case STATE_RECORDING:
    		mRecorder.stop();
    		mRecorder.release();
    		registerAudio();
    		pathText.setText("");
    		pathText.setEnabled(true);
    		recordButton.setText("");
    		break;
    	}
    }
    
    private void initRecorder(){
    	mediaPath = Environment
    			.getExternalStorageDirectory()
    			.getPath()+"/"+ pathText.getText().toString()+".mp3";
    	
		mediaFile = new File(mediaPath);
		
    	mRecorder = new MediaRecorder();
        mRecorder.setAudioSource(MediaRecorder.AudioSource.MIC);
        mRecorder.setOutputFormat(MediaRecorder.OutputFormat.MPEG_4);
        
        mRecorder.setAudioEncoder(MediaRecorder.AudioEncoder.AMR_NB);
		mRecorder.setOutputFile(mediaFile.getAbsolutePath());
		
		try {
			mRecorder.prepare();
		} catch (IllegalStateException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
    }
    
    private void registerAudio(){
    	ContentValues values = new ContentValues();
    	values.put(Audio.Media.TITLE, "Test Music");
    	values.put(Audio.Media.ALBUM, "Test Album");
    	values.put(Audio.Media.ARTIST, "Test Artist");
    	values.put(Audio.Media.MIME_TYPE, "audio/mpeg");
    	values.put(Audio.Media.IS_MUSIC, 1);
    	values.put(Audio.Media.DISPLAY_NAME, mediaFile.getName());
    	values.put(Audio.Media.DATA, mediaFile.getPath());
    	values.put(Audio.Media.SIZE, mediaFile.length());
    	getContentResolver().insert(Audio.Media.EXTERNAL_CONTENT_URI, values);
    	Toast.makeText(this, " Ǿϴ.", Toast.LENGTH_SHORT).show();
    }
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        pathText = (EditText)findViewById(R.id.pathText);
        recordButton = (Button)findViewById(R.id.recordButton);
                               
        recordButton.setOnClickListener(new OnClickListener(){

			@Override
			public void onClick(View v) {
				procAudio(RECORDING_STATE);
			}
        });  
    }     
    
    
}