/* 
 * Copyright (C) 2010 Tae-Ho, Kim.
 * This contains some code from ApiDemos, The Android Open Source Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.androidhuman.example.CameraPreview2;

import java.io.IOException;

import android.app.Activity;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.hardware.Camera;
import android.hardware.Camera.PictureCallback;
import android.os.Bundle;
import android.provider.MediaStore;
import android.view.LayoutInflater;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.RelativeLayout;
import android.widget.Toast;

public class CameraPreview extends Activity {    
    private Preview mPreview;
    private Button getPictureButton;
    
    @Override
	protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
              
        mPreview = new Preview(this);
               
        LayoutInflater inflater = getLayoutInflater();
        RelativeLayout rl = (RelativeLayout)inflater.inflate(R.layout.main, null);
        
        getPictureButton = (Button)rl.findViewById(R.id.cameraButton);
        getPictureButton.setOnClickListener(new OnClickListener(){

			@Override
			public void onClick(View v) {
				mPreview.getPicture();
			}
        });
        
        FrameLayout fl = new FrameLayout(this);
        fl.addView(mPreview);
        fl.addView(rl);
        setContentView(fl);
    }
    
    class Preview extends SurfaceView implements SurfaceHolder.Callback {
        SurfaceHolder mHolder;
        Camera mCamera;
        Context mCtx;
        
        Preview(Context context) {
            super(context);
            mCtx = context;
            mHolder = getHolder();
            mHolder.addCallback(this);
            mHolder.setType(SurfaceHolder.SURFACE_TYPE_PUSH_BUFFERS);
        }

        public void surfaceCreated(SurfaceHolder holder) {
            mCamera = Camera.open();
            try {
               mCamera.setPreviewDisplay(holder);
            } catch (IOException exception) {
                mCamera.release();
                mCamera = null;
            }
        }
        
        public void surfaceChanged(SurfaceHolder holder, int format, int w, int h) {
            Camera.Parameters parameters = mCamera.getParameters();
            parameters.setPreviewSize(w, h);
            mCamera.setParameters(parameters);
            mCamera.startPreview();
        }

        public void surfaceDestroyed(SurfaceHolder holder) {
            mCamera.stopPreview();
            mCamera.release();
            mCamera = null;
        }
        
        public void getPicture(){
        	mCamera.takePicture(null, null, new PictureCallback(){

    			@Override
    			public void onPictureTaken(byte[] data, Camera camera) {
    				Bitmap picture = BitmapFactory.decodeByteArray(data, 0, data.length);
    				MediaStore.Images.Media.insertImage(getContentResolver(), picture, "Test", "Test image");
    				Toast.makeText(CameraPreview.this, " Ǿϴ,", Toast.LENGTH_LONG).show();
    				mCamera.startPreview();
    			}
        	});
        }
    }
}

