package com.androidhuman.example.DialogExample;

import android.app.Activity;
import android.app.DatePickerDialog;
import android.app.Dialog;
import android.app.TimePickerDialog;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.DatePicker;
import android.widget.TextView;
import android.widget.TimePicker;

public class DialogExample extends Activity implements OnClickListener{
    
	private static final int DIALOG_DATE = 0;
    private static final int DIALOG_TIME = 1;
    
    private TextView mDateText;
    private TextView mTimeText;
    
    private DatePickerDialog.OnDateSetListener dateListener = 
    	new DatePickerDialog.OnDateSetListener() {
		
		@Override
		public void onDateSet(DatePicker view, int year, int monthOfYear,
				int dayOfMonth) {
			mDateText.setText(year+" "+(monthOfYear+1)+" "+dayOfMonth+"");
		}
	};
	
	private TimePickerDialog.OnTimeSetListener timeListener = 
		new TimePickerDialog.OnTimeSetListener() {
			
			@Override
			public void onTimeSet(TimePicker view, int hourOfDay, int minute) {
				mTimeText.setText(hourOfDay+" "+minute+"");
			}
		};
    
    @Override
    public void onCreate(Bundle savedInstanceState){
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        Button datePickButton = (Button)findViewById(R.id.datePickButton);
        Button timePickButton = (Button)findViewById(R.id.timePickButton);
        Button callDialogButton = (Button)findViewById(R.id.callDialogActivity);
        mDateText = (TextView)findViewById(R.id.dateText);
        mTimeText = (TextView)findViewById(R.id.timeText);
        
        datePickButton.setOnClickListener(this);
        timePickButton.setOnClickListener(this);
        callDialogButton.setOnClickListener(this);
    }

	@Override
	public void onClick(View v) {
		switch(v.getId()){
		case R.id.datePickButton:
			showDialog(DIALOG_DATE);
			break;
		case R.id.timePickButton:
			showDialog(DIALOG_TIME);
			break;
		case R.id.callDialogActivity:
			startActivity(new Intent(this, DialogActivity.class));
			break;
		}
	}
	
	@Override
	protected Dialog onCreateDialog(int id){
		switch(id){
		case DIALOG_DATE:
			return new DatePickerDialog(this, dateListener, 2010, 0, 15);
		case DIALOG_TIME:
			return new TimePickerDialog(this, timeListener, 10, 30, false);
		}
		return null;
	}
}