package com.androidhuman.example.PhoneStateView;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.telephony.PhoneStateListener;
import android.telephony.ServiceState;
import android.telephony.TelephonyManager;
import android.widget.TextView;

public class PhoneStateView extends Activity {
    private TelephonyManager telManager;
    private String serviceState;
    private String callState;
    private TextView stateText;
    
    private PhoneStateListener listener = new PhoneStateListener(){
    	public void onServiceStateChanged(ServiceState state){
    		switch(state.getState()){
    		case ServiceState.STATE_IN_SERVICE:
    			serviceState = "In service";
    			break;
    		case ServiceState.STATE_EMERGENCY_ONLY:
    			serviceState = "Emergency only";
    			break;
    		case ServiceState.STATE_OUT_OF_SERVICE:
    			serviceState = "Out of service";
    			break;
    		case ServiceState.STATE_POWER_OFF:
    			serviceState = "Radio off";
    			break;
    		}
    		update();
    	}
    	
    	public void onCallStateChanged(int state, String incomingNumber){
    		switch(state){
    		case TelephonyManager.CALL_STATE_IDLE:
    			callState = "Idle";
    			break;
    		case TelephonyManager.CALL_STATE_OFFHOOK:
    			callState = "offHook";
    			break;
    		case TelephonyManager.CALL_STATE_RINGING:
    			callState = "Ringing";
    			break;
    		}
    		update();
    	}
    };
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        stateText = new TextView(this);
        telManager = (TelephonyManager)getSystemService(Context.TELEPHONY_SERVICE);
        telManager.listen(listener, PhoneStateListener.LISTEN_SERVICE_STATE | 
        		PhoneStateListener.LISTEN_CALL_STATE);
        setContentView(stateText);
    }
    
    private void update(){
    	StringBuilder builder = new StringBuilder();
        builder.append("Number : " + telManager.getLine1Number())
        	.append("\nOperator : " + telManager.getNetworkOperatorName())
        	.append("\nMCC+MNC : " + telManager.getNetworkOperator())
        	.append("\nIMEI : " + telManager.getDeviceId())
        	.append("\nSim S/N : " + telManager.getSimSerialNumber())
        	.append("\nSIM Operator : " + telManager.getSimOperatorName())
        	.append("\nService state : " + serviceState)
        	.append("\nCall state : " + callState);
        stateText.setText(builder.toString());
    }
    
    @Override
    public void onStop(){
    	super.onStop();
    	telManager.listen(listener, PhoneStateListener.LISTEN_NONE);
    }
}