package com.androidhuman.example.SimpleAIDL;

import android.app.Activity;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Bundle;
import android.os.IBinder;
import android.os.RemoteException;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.Toast;

public class SimpleAIDLActivity extends Activity implements OnClickListener{
    private Button bindServiceButton;
    private Button getMessageButton;
    private Button unbindServiceButton;
    private ISimpleAIDL mSimpleService = null;
    private boolean isBound;
    
    private ServiceConnection mServiceConnection = new ServiceConnection(){
		@Override
		public void onServiceConnected(ComponentName name, IBinder service) {
			mSimpleService = ISimpleAIDL.Stub.asInterface(service);
		}

		@Override
		public void onServiceDisconnected(ComponentName name) {
			mSimpleService = null;
		}
    };
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        bindServiceButton = (Button)findViewById(R.id.bindService);
        getMessageButton = (Button)findViewById(R.id.getCurrentTime);
        unbindServiceButton = (Button)findViewById(R.id.unbindService);
        
        bindServiceButton.setOnClickListener(this);
        getMessageButton.setOnClickListener(this);
        unbindServiceButton.setOnClickListener(this);
    }

	@Override
	public void onClick(View v) {
		switch(v.getId()){
		case R.id.bindService:
			bindService(new Intent(this, SimpleService.class), 
					mServiceConnection, Context.BIND_AUTO_CREATE);
			isBound = true;
			break;
			
		case R.id.getCurrentTime:
			if(isBound){
				try {
					Toast.makeText(this, 
							mSimpleService.getCurrentTime(System.currentTimeMillis()), 
							Toast.LENGTH_SHORT).show();
				} catch (RemoteException e) {
					e.printStackTrace();
				}
			}else{
				Toast.makeText(this, "񽺿 ε ʾҽϴ.", 
						Toast.LENGTH_SHORT).show();
			}
			break;
			
		case R.id.unbindService:
			unbindService(mServiceConnection);
			isBound = false;
			break;
		}
	}
	
	@Override
	public void onStop(){
		super.onStop();
		if(isBound){
			unbindService(mServiceConnection);
			isBound = false;
		}
	}
	
}