package com.androidhuman.example.TwitterExample;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import twitter4j.Status;
import twitter4j.TwitterException;
import android.app.Dialog;
import android.app.ListActivity;
import android.app.ProgressDialog;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.SimpleAdapter;
import android.widget.Toast;

public class Timeline extends ListActivity{
	
	private static final int PROGRESS_DIALOG = 0;
 
    private static final int MSG_GET_TIMELINE_COMPLETED = 0;
    private static final int MSG_AUTH_COMPLETED = 1;
	
	private List<Status> timeline;
    private ArrayList<HashMap<String, String>> list;
    private SimpleAdapter adapter;
    
	private ProgressDialog mProgressDialog;
    private TwitterSupport support;
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        support = new TwitterSupport(this);
    }
    
    @Override
    public void onResume(){
    	super.onResume();
    	if(support.isAuthRequired()){
    		support.requestAuthToken();
    	}else{
    		Log.i("TwitterExample", "Getting Auth Data...");
    		support.getAuthToken(); 
    		requestTimeline();
    	}
    }
    
    private void requestTimeline(){
    	showDialog(PROGRESS_DIALOG);
    	new Thread(new Runnable(){

			@Override
			public void run() {
				getTimeline();
				handler.sendEmptyMessage(MSG_GET_TIMELINE_COMPLETED);
				dismissDialog(PROGRESS_DIALOG);
			}
    	}).start();
    }
    
    private void getTimeline(){
    	timeline = null;
    	list = new ArrayList<HashMap<String, String>>();
    	
    	try{
			timeline = support.getTimeline();
			
			for(Status status: timeline){
				HashMap<String, String> item = new HashMap<String, String>();
				item.put("username", status.getUser().getScreenName());
				item.put("message", status.getText());
				list.add(item);
			}
			
		}catch(TwitterException e){ 
			e.printStackTrace();
		}
    } 
	
    private Handler handler = new Handler(){
    	@Override
    	public void handleMessage(Message msg){
    		switch(msg.what){
    		case MSG_GET_TIMELINE_COMPLETED:
    			refreshList();
    			break;
    			
    		case MSG_AUTH_COMPLETED:
    			Toast.makeText(Timeline.this, " ϷǾϴ.", Toast.LENGTH_LONG).show();
    			break;
    		}
    	}	
    };
    
    private void refreshList(){
    	String[] from = new String[]{"username", "message"};
    	int[] to = new int[]{R.id.username, R.id.message};
    	
    	adapter = new SimpleAdapter(this, list, R.layout.row, from, to);
    	setListAdapter(adapter);
    }
    
    @Override
    protected Dialog onCreateDialog(int id){
    	super.onCreateDialog(id);
    	switch(id){
    	case PROGRESS_DIALOG:
    		mProgressDialog = new ProgressDialog(this);
    		mProgressDialog.setMessage("ŸӶ ...");
    		return mProgressDialog;
    	}
    	return null;
    }
    
    @Override
    public void onNewIntent(final Intent intent){
    	super.onNewIntent(intent);
		try {
			support.saveAccessToken(intent.getData());
			handler.sendEmptyMessage(MSG_AUTH_COMPLETED);
		} catch (TwitterException e) {
			e.printStackTrace();
		}
    }
    
    //////////////////// ޴ ///////////////////////

    private static final int MENU_SEND_TWEET = 0;
    private static final int MENU_REFRESH = 1;

	@Override
	public boolean onCreateOptionsMenu(Menu menu){
		super.onCreateOptionsMenu(menu);
		menu.add(0, MENU_SEND_TWEET, Menu.NONE, "Ʈ ۼ");
		menu.add(1, MENU_REFRESH, Menu.NONE, "ΰħ");
		return true;
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item){
		super.onOptionsItemSelected(item);
		switch(item.getItemId()){
		case MENU_SEND_TWEET:
			startActivity(new Intent(this, SendTweet.class));
			return true;	
		case MENU_REFRESH:
			requestTimeline();
			return true;
		}
		return false;
	}
}