/* 
 * Copyright (C) 2010 Tae-Ho, Kim.
 * This contains some code from ApiDemos/CameraPreview,
 * from The Android Open Source Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.androidhuman.example.VideoRecorder;

import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;

import android.app.Activity;
import android.content.ContentValues;
import android.content.Context;
import android.hardware.Camera;
import android.media.MediaRecorder;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.provider.MediaStore.Video;
import android.view.LayoutInflater;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.RelativeLayout;
import android.widget.Toast;

public class VideoRecorder extends Activity {
	private static final int STATE_IDLE = 0;
	private static final int STATE_RECORDING = 1;
	
	private static int RECORDING_STATE = STATE_IDLE;
    private Preview mPreview;
    private Button takeVideoButton;
    
    @Override
	protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
              
        mPreview = new Preview(this);
               
        LayoutInflater inflater = getLayoutInflater();
        RelativeLayout rl = (RelativeLayout)inflater.inflate(R.layout.main, null);
        
        takeVideoButton = (Button)rl.findViewById(R.id.cameraButton);
        takeVideoButton.setOnClickListener(new OnClickListener(){

			@Override
			public void onClick(View v) {
				mPreview.procVideo(RECORDING_STATE);
			}
        });
        
        FrameLayout fl = new FrameLayout(this);
        fl.addView(mPreview);
        fl.addView(rl);
        setContentView(fl);
    }
    
    class Preview extends SurfaceView implements SurfaceHolder.Callback {
        SurfaceHolder mHolder;
        Camera mCamera;
        Context mCtx;
        MediaRecorder mRecorder;
        
        String filePath;
        File videoFile = null;
       
        Preview(Context context) {
            super(context);
            mCtx = context;
            mHolder = getHolder();
            mHolder.addCallback(this);
            mHolder.setType(SurfaceHolder.SURFACE_TYPE_PUSH_BUFFERS);
        }

        public void surfaceCreated(SurfaceHolder holder) {
            mCamera = Camera.open();
            try {
               mCamera.setPreviewDisplay(holder);
            } catch (IOException exception) {
                mCamera.release();
                mCamera = null;
            }
        }
        
        public void surfaceChanged(SurfaceHolder holder, int format, int w, int h) {
        	Camera.Parameters parameters = mCamera.getParameters();
            parameters.setPreviewSize(320, 240);
            mCamera.setParameters(parameters);
            mCamera.startPreview();
        }

        public void surfaceDestroyed(SurfaceHolder holder) {
            mCamera.stopPreview();
            mCamera.release();
            mCamera = null;
        }
        
        private void initRecorder(){
        	 filePath = Environment
				.getExternalStorageDirectory()
				.getPath()+ "/" + createName(System.currentTimeMillis());
	         try {
	         	videoFile = new File(filePath);
					videoFile.createNewFile();
				} catch (IOException e){
					e.printStackTrace();
				}
			
        	mRecorder = new MediaRecorder();
        
            mCamera.unlock();
        	mRecorder.setCamera(mCamera);
        	
            mRecorder.setAudioSource(MediaRecorder.AudioSource.MIC);
            mRecorder.setVideoSource(MediaRecorder.VideoSource.CAMERA);
          
            mRecorder.setOutputFormat(MediaRecorder.OutputFormat.THREE_GPP);
           
            mRecorder.setVideoSize(320, 240);
            mRecorder.setVideoFrameRate(15);
            
            mRecorder.setAudioEncoder(MediaRecorder.AudioEncoder.DEFAULT);
            mRecorder.setVideoEncoder(MediaRecorder.VideoEncoder.H264);
            
            mRecorder.setPreviewDisplay(mHolder.getSurface());
            mRecorder.setOutputFile(filePath);
            
            try {
				mRecorder.prepare();
			} catch (IllegalStateException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			}
        }
        
        private String createName(long dateTaken){
        	Date date = new Date(dateTaken);
        	SimpleDateFormat dateFormat = 
        		new SimpleDateFormat("yyyy-MM-dd HH.mm.ss");
        	return dateFormat.format(date)+".3gp";
        }
        
        private void registerVideo(){
        	ContentValues values = new ContentValues();
        	values.put(Video.Media.TITLE, "Test video");
        	values.put(Video.Media.DISPLAY_NAME, videoFile.getName());
        	values.put(Video.Media.DATE_TAKEN, System.currentTimeMillis());
        	values.put(Video.Media.MIME_TYPE, "video/3gp");
        	values.put(Video.Media.DATA, videoFile.getPath());
        	values.put(Video.Media.SIZE, videoFile.length());
        	mCtx.getContentResolver().insert(MediaStore.Video.Media.EXTERNAL_CONTENT_URI, values);
        	Toast.makeText(VideoRecorder.this, " Ǿϴ.", Toast.LENGTH_SHORT).show();
        }
        
        public void procVideo(int state){
        	switch(state){
        	case STATE_IDLE:
        		initRecorder();
        		mRecorder.start();
        		RECORDING_STATE = STATE_RECORDING;
        		takeVideoButton.setText("");
        		break;
        		
        	case STATE_RECORDING:
        		mRecorder.stop();
        		RECORDING_STATE = STATE_IDLE;
        		mRecorder.release();
        		registerVideo();
        		mCamera.lock();
        		takeVideoButton.setText("Կ");
        		break;
        	}
        }
    }
}

