/* 
 * Copyright (C) 2010 Tae-Ho, Kim.
 * This example contains some code from ApiDemos,
 * The Android Open Source Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.androidhuman.example.VoiceRecognitionExample;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;

import android.app.Activity;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.content.pm.ResolveInfo;
import android.os.Bundle;
import android.speech.RecognizerIntent;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

public class VoiceRecognitionExample extends Activity {
    private Button recogButton;
    private TextView recogText;
    private static int VOICE_REQ_CODE = 0;
    
    boolean isVoiceRecognitionAvailable(){
    	PackageManager pm = getPackageManager();
        List<ResolveInfo> activities = pm.queryIntentActivities(
                new Intent(RecognizerIntent.ACTION_RECOGNIZE_SPEECH), 0);
        if (activities.size() != 0)
        	return true;
        else
        	return false;
    }
    
    void startVoiceRecognition(){
    	Intent intent = new Intent(RecognizerIntent.ACTION_RECOGNIZE_SPEECH);
    	intent.putExtra(RecognizerIntent.EXTRA_LANGUAGE, Locale.getDefault().toString());
        intent.putExtra(RecognizerIntent.EXTRA_LANGUAGE_MODEL,
                RecognizerIntent.LANGUAGE_MODEL_FREE_FORM);
        intent.putExtra(RecognizerIntent.EXTRA_MAX_RESULTS, 5);
        intent.putExtra(RecognizerIntent.EXTRA_PROMPT, "ν ");
        startActivityForResult(intent, VOICE_REQ_CODE);
    }
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        recogText = (TextView)findViewById(R.id.text);
        recogButton = (Button)findViewById(R.id.speak_now);
        
        recogButton.setOnClickListener(new OnClickListener(){

			@Override
			public void onClick(View v) {
				if(isVoiceRecognitionAvailable())
					startVoiceRecognition();
				else
					Toast.makeText(VoiceRecognitionExample.this, "νıⰡ ϴ.", Toast.LENGTH_LONG).show();
			}
        });
    }
  
    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data){
    	super.onActivityResult(requestCode, resultCode, data);
    	if(requestCode == VOICE_REQ_CODE && resultCode == Activity.RESULT_OK){
    		ArrayList<String> results = data.getStringArrayListExtra(RecognizerIntent.EXTRA_RESULTS);
    		recogText.setText(results.get(0));
    	}
    }
}